summaryrefslogtreecommitdiff
path: root/src/key.c
diff options
context:
space:
mode:
authorVito Caputo <vcaputo@gnugeneration.com>2017-03-22 18:36:54 -0700
committerVito Caputo <vcaputo@gnugeneration.com>2017-03-25 16:51:17 -0700
commit36daa7b60f0545a79482d174c778293ec831e03e (patch)
treee5d6b8d93d5ed66db08141c7d24372e808d17d3a /src/key.c
parent3657ce966227e9be0334540178ca578bc8d5ad0d (diff)
overlays: rename overlays->charts
vmon introduces a non-overlay usage, monitors is correct but ambiguous, graphs is also amiguous, charts is short and distinctive. renaming of the files comes in a separate, future commit.
Diffstat (limited to 'src/key.c')
-rw-r--r--src/key.c10
1 files changed, 5 insertions, 5 deletions
diff --git a/src/key.c b/src/key.c
index ae72882..e795a93 100644
--- a/src/key.c
+++ b/src/key.c
@@ -343,23 +343,23 @@ void vwm_key_pressed(vwm_t *vwm, Window win, XKeyPressedEvent *keypress)
}
break;
- case XK_semicolon: /* toggle composited overlays */
+ case XK_semicolon: /* toggle composited charts */
vwm_composite_toggle(vwm);
break;
case XK_apostrophe: /* reset snowflakes of the focused window */
- if (vwin && vwin->xwindow->overlay) {
- vwm_overlay_reset_snowflakes(vwm->overlays, vwin->xwindow->overlay);
+ if (vwin && vwin->xwindow->chart) {
+ vwm_chart_reset_snowflakes(vwm->charts, vwin->xwindow->chart);
vwm_composite_damage_win(vwm, vwin->xwindow);
}
break;
case XK_Right: /* increase sampling frequency */
- vwm_overlays_rate_increase(vwm->overlays);
+ vwm_charts_rate_increase(vwm->charts);
break;
case XK_Left: /* decrease sampling frequency */
- vwm_overlays_rate_decrease(vwm->overlays);
+ vwm_charts_rate_decrease(vwm->charts);
break;
default:
© All Rights Reserved